@@ -17,11 +17,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -238,7 +234,7 @@ int main(int argc, char **argv)
 	    {
 		must_continue++;
 	    }
-	    else
+	    else if (!host->done)
 	    {
 		host->done = 1;
 		validhosts--;
@@ -278,7 +274,7 @@ int main(int argc, char **argv)
 	}
 	
 	delay = 100;
-	while ((host = wait_for_reply(hosts, numhosts, rcvsock, delay))
+	if ((host = wait_for_reply(hosts, numhosts, rcvsock, delay))
 	          != NULL)
 	{
 	    gettimeofday(&now, &tz);
@@ -574,6 +570,9 @@ static void send_probe(int seq, int ttl, struct opacket *op,
     up->uh_dport = htons(port + seq);
     up->uh_ulen = htons((u_short)(sizeof(struct opacket) - sizeof(struct ip)));
     up->uh_sum = 0;
+    
+    if (verbose >= 4)
+    	fprintf(stderr, "%-35s>>\n", host->hostname);
 
     i = sendto(sndsock, op, sizeof(struct opacket), 0,
 	       (struct sockaddr *)&host->addr, sizeof(host->addr));
